! $Id: IdentifierMap.f90 2323 2016-08-15 03:15:16Z ian $
! ff08 source code copyright 2016 M.E.G.M.S.  See LICENCE.txt for licence.
!> @file
!! Defines the IdentifierMapMod module.


!*******************************************************************************
!!
!> Worker module for the identifier map, that INCLUDE's the generic code.
!!
!! This module should not be used by anything other than IdentifierMapMod.

MODULE identifier_map_implementation
  
  USE Debug, ONLY: DbgChecks
  ! The RBTree.i90 stretch of source requires the value type to be known 
  ! as value_type, and the key type to be known as key_type.  Set that up 
  ! here using USE renaming.
  USE Strings, value_type => String, key_type => String
  
  IMPLICIT NONE
  
  PRIVATE
  
  !-----------------------------------------------------------------------------
  
  ! The RBTree.i90 stretch of source requires a LOGICAL data object called 
  ! debug_flag to indicate whether additional debugging should be carried 
  ! out.  Tie the value of that data object to the FF08 global debugging flag.
  LOGICAL, PARAMETER :: debug_flag = DbgChecks
  
  PUBLIC :: Insert
  PUBLIC :: Query
  PUBLIC :: Get
  PUBLIC :: RBTree
  
  ! Poor mans templating.  See the comments in the included source for 
  ! more information.
  INCLUDE 'RBTree.i90'
  
  
  !*****************************************************************************
  !!
  !> Compares two keys.
  !!
  !! @param[in]     lhs               One of the keys to compare.
  !!
  !! @param[in]     rhs               The other key to compare.
  !!
  !! @returns -1 if @a lhs is lexographically less than @a rhs, 0 if 
  !! @a lhs is considered the same as @a 
  !!
  !! This satisifies another requirement of the included generic code.
  
  FUNCTION compare_key(lhs, rhs)
    
    !---------------------------------------------------------------------------
    ! Arguments
    
    TYPE(key_type), INTENT(IN) :: lhs
    TYPE(key_type), INTENT(IN) :: rhs
    
    INTEGER :: compare_key
    
    !***************************************************************************
    
    IF (lhs%item < rhs%item) THEN
      compare_key = -1
    ELSE IF (lhs%item == rhs%item) THEN
      compare_key = 0
    ELSE
      compare_key = 1
    END IF
    
  END FUNCTION compare_key
  
END MODULE identifier_map_implementation


!*******************************************************************************
!!
!> Defines the IdentifierMap type and supporting procedures.

MODULE IdentifierMapMod
  
  ! Use use renaming to rename the type exposed by the generic include code 
  ! to something specific to the role of the map for clients.
  USE identifier_map_implementation, IdentifierMap => RBTree
  
  IMPLICIT NONE
  
  PRIVATE
  
  ! The bits and bobs from the generic code that clients might require.
  PUBLIC :: IdentifierMap
  PUBLIC :: Query
  PUBLIC :: Get
  PUBLIC :: Insert
  
END MODULE IdentifierMapMod
