! $Id: SyntaxTerms.f90 2153 2016-05-30 03:21:54Z ian $
! ff08 source code copyright 2012 M.E.G.M.S.  See LICENCE.txt for licence.
!> @file
!! Defines the SyntaxParts module.


!*******************************************************************************
!!
!> Identifiers for syntax terms.
!!
!! Syntax terms are those rules that are finer than statements.
!!
!! Only terms that have some relevant to the parser are included here.
!!
!! There is a significant chance that we will obliterate this module.  
!! Failing that, it needs to be merged with the "component" concepts that 
!! is scattered through out the parsing routines.
!!
!! Along with SyntaxParts and Statements, we need to thing about how 
!! we handle migration to a later standard revision.  Interpretations can 
!! also introduce syntax rules like "R123a", which we would have to represent 
!! with some sort of out of band solution.
!!
!! StNode and ParseNode extensions also have their own internal concept 
!! of the syntax rule that they belong to.
!!
!! Perhaps the F2008 number is just a (relatively) opaque key, set as the 
!! value of an appropriately named derived type, that can be used to lookup 
!! from an array of derived type the text variant of the syntax rule and 
!! syntax rule name.  Different standard revision - different lookup table.
!!
!! The pn and sn private types in the SyntaxParts and Statements modules go 
!! some way down this path, though those derived type definitions are 
!! incomplete.

MODULE SyntaxTerms
  
  IMPLICIT NONE
  
  !-----------------------------------------------------------------------------
  ! Clause 4 - Types
  
  INTEGER, PARAMETER :: isrTypeSpec = 402
  INTEGER, PARAMETER :: isrDeclarationTypeSpec = 403
  
  INTEGER, PARAMETER :: isrComplexLiteralConstant = 417
  
  INTEGER, PARAMETER :: isrStructureConstructor = 455
  
  INTEGER, PARAMETER :: isrArrayConstructor = 468
  INTEGER, PARAMETER :: isrACValue = 472
  INTEGER, PARAMETER :: isrACImpliedDoControl = 474
  
  !-----------------------------------------------------------------------------
  
  INTEGER, PARAMETER :: isrEntityDecl = 503
  
  INTEGER, PARAMETER :: isrNullInit = 506
  
  INTEGER, PARAMETER :: isrLanguageBindingSpec = 508
  
  INTEGER, PARAMETER :: isrIntentSpec = 523
  
  INTEGER, PARAMETER :: isrDataImpliedDo = 537
  
  INTEGER, PARAMETER :: isrNamelistGroupObject = 564
  INTEGER, PARAMETER :: isrEquivalenceSet = 566
  
  INTEGER, PARAMETER :: isrCommonBlockObject = 569
  
  !-----------------------------------------------------------------------------
  ! Clause 6 - Use of data objects.
  
  INTEGER, PARAMETER :: isrDesignator = 601
  INTEGER, PARAMETER :: isrVariable = 602
  
  INTEGER, PARAMETER :: isrDataRef = 611
  INTEGER, PARAMETER :: isrPartRef = 612
  INTEGER, PARAMETER :: isrStructureComponent = 613
  
  !-----------------------------------------------------------------------------
  ! Clause 7 - Expressions and assignment.
  
  INTEGER, PARAMETER :: isrExpr = 722
  
  INTEGER, PARAMETER :: isrForallHeader = 752
  
  !-----------------------------------------------------------------------------
  ! Clause 9 - Input/output statements
  
  INTEGER, PARAMETER :: isrIOUnit = 901
  INTEGER, PARAMETER :: isrConnectSpec = 905
  INTEGER, PARAMETER :: isrCloseSpec = 909
  INTEGER, PARAMETER :: isrIOControlSpec = 913
  
  INTEGER, PARAMETER :: isrFormat = 915
  INTEGER, PARAMETER :: isrInputItem = 916
  INTEGER, PARAMETER :: isrOutputItem = 917
  INTEGER, PARAMETER :: isrIoImpliedDo = 918
  
  INTEGER, PARAMETER :: isrPositionSpec = 927
  INTEGER, PARAMETER :: isrFlushSpec = 929
  INTEGER, PARAMETER :: isrInquireSpec = 931
  
  !-----------------------------------------------------------------------------
  ! Clause 11 - Program Units.
  
  INTEGER, PARAMETER :: isrRename = 1111
  INTEGER, PARAMETER :: istOnly = 1112
  
  !-----------------------------------------------------------------------------
  ! Clause 12 - Procedures.
  
  INTEGER, PARAMETER :: isrGenericSpec = 1207
  
  INTEGER, PARAMETER :: isrProcInterface = 1212
  INTEGER, PARAMETER :: isrProcAttrSpec = 1213
  INTEGER, PARAMETER :: isrProcDecl = 1214
  
  INTEGER, PARAMETER :: isrFunctionReference = 1219
  
  INTEGER, PARAMETER :: isrActualArgSpec = 1222
  
END MODULE SyntaxTerms
